logo       
Google Custom Search
    AddThis Social Bookmark Button

[SSI] openssi/kernel/cluster/ssi/cfs cfs_chard.c,1.2.2.1,1.2.2.2 cfs_server: msg#00518

Subject: [SSI] openssi/kernel/cluster/ssi/cfs cfs_chard.c,1.2.2.1,1.2.2.2 cfs_server.c,1.4,1.4.2.1 cfs_subr.c,1.2.2.3,1.2.2.4 cfs_svc.c,1.4,1.4.2.1 cfsproc.c,1.1.2.11,1.1.2.12 cfstok.c,1.1.2.4,1.1.2.5 inode.c,1.9.2.6,1.9.2.7 svrcfs.c,1.4,1.4.2.1 symlink.c,1.3.2.1,1.3.2.2 write.c,1.2,1.2.2.1
Update of /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv21520/cluster/ssi/cfs

Modified Files:
      Tag: OPENSSI-RH
        cfs_chard.c cfs_server.c cfs_subr.c cfs_svc.c cfsproc.c 
        cfstok.c inode.c svrcfs.c symlink.c write.c 
Log Message:
Fix all CFS files to uniformly use SSI_XXX


Index: cfs_server.c
===================================================================
RCS file: 
/cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfs_server.c,v
retrieving revision 1.4
retrieving revision 1.4.2.1
diff -u -d -r1.4 -r1.4.2.1
--- cfs_server.c        3 Oct 2003 23:25:47 -0000       1.4
+++ cfs_server.c        29 Mar 2004 23:43:08 -0000      1.4.2.1
@@ -465,7 +465,7 @@
                else {
                        nlp = NSC_NODELIST_ALLOC();
                        if (nlp != NULL) {
-                               /* XXX: Is this safe without locking? */
+                               /* SSI_XXX: Is this safe without locking? */
                                /* CTABLE_SHR_LOCK(); */
                                rootip = sb->s_root->d_inode;
                                if (rootip != NULL)

Index: cfsproc.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfsproc.c,v
retrieving revision 1.1.2.11
retrieving revision 1.1.2.12
diff -u -d -r1.1.2.11 -r1.1.2.12
--- cfsproc.c   27 Mar 2004 05:08:25 -0000      1.1.2.11
+++ cfsproc.c   29 Mar 2004 23:43:08 -0000      1.1.2.12
@@ -1341,7 +1341,7 @@
                filp->f_op    = fops_get(inode->i_fop);
                atomic_set(&filp->f_count, 1);
                filp->f_dentry = dentry;        /* Not held again!!!! */
-               filp->f_vfsmnt = NULL;          /* XXX: Do I need something? */
+               filp->f_vfsmnt = NULL;          /* SSI_XXX: Do I need 
something? */
 
                filp->f_flags = O_RDONLY|O_LARGEFILE;
                filp->f_mode  = FMODE_READ;
@@ -1367,7 +1367,7 @@
         * we've gone remote internally in the cluster, so something
         * else must go here.
         */
-       fl->fl_owner = NULL;    /* XXX: Do I need a better value here? */
+       fl->fl_owner = NULL;    /* SSI_XXX: Do I need a better value here? */
        fl->fl_pid = args->cfrla_pid;   /* Cluster wide unique */
        fl->fl_file = filp;
        fl->fl_flags = args->cfrla_flags;
@@ -1425,7 +1425,7 @@
                filp->f_op    = fops_get(inode->i_fop);
                atomic_set(&filp->f_count, 1);
                filp->f_dentry = dentry;
-               filp->f_vfsmnt = NULL;          /* XXX: Do I need something? */
+               filp->f_vfsmnt = NULL;          /* SSI_XXX: Do I need 
something? */
 
                filp->f_flags = O_RDONLY|O_LARGEFILE;
                filp->f_mode  = FMODE_READ;
@@ -1451,7 +1451,7 @@
         * we've gone remote internally in the cluster, so something
         * else must go here.
         */
-       fl->fl_owner = NULL;    /* XXX: Do I need a better value here? */
+       fl->fl_owner = NULL;    /* SSI_XXX: Do I need a better value here? */
        fl->fl_pid = args->cfrla_pid;   /* Cluster wide unique */
        fl->fl_file = filp;
        fl->fl_flags = args->cfrla_flags;
@@ -1519,7 +1519,7 @@
                filp->f_op    = fops_get(inode->i_fop);
                atomic_set(&filp->f_count, 1);
                filp->f_dentry = dentry;
-               filp->f_vfsmnt = NULL;          /* XXX: Do I need something? */
+               filp->f_vfsmnt = NULL;          /* SSI_XXX: Do I need 
something? */
 
                filp->f_flags = O_RDONLY|O_LARGEFILE;
                filp->f_mode  = FMODE_READ;
@@ -1545,7 +1545,7 @@
         * we've gone remote internally in the cluster, so something
         * else must go here.
         */
-       fl->fl_owner = NULL;    /* XXX: Do I need a better value here? */
+       fl->fl_owner = NULL;    /* SSI_XXX: Do I need a better value here? */
        fl->fl_pid = args->cla_pid;     /* Cluster wide unique */
        fl->fl_file = filp;
        fl->fl_flags = args->cla_flags;

Index: symlink.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/symlink.c,v
retrieving revision 1.3.2.1
retrieving revision 1.3.2.2
diff -u -d -r1.3.2.1 -r1.3.2.2
--- symlink.c   29 Jan 2004 03:03:50 -0000      1.3.2.1
+++ symlink.c   29 Mar 2004 23:43:08 -0000      1.3.2.2
@@ -54,9 +54,9 @@
        void *buffer = kmap(page);
        int error;
 
-       lock_kernel();          /* XXX */
+       lock_kernel();          /* SSI_XXX */
        error = CFS_PROTO(inode)->readlink(inode, buffer, PAGE_CACHE_SIZE);
-       unlock_kernel();        /* XXX */
+       unlock_kernel();        /* SSI_XXX */
        if (error < 0)
                goto error;
        SetPageUptodate(page);

Index: write.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/write.c,v
retrieving revision 1.2
retrieving revision 1.2.2.1
diff -u -d -r1.2 -r1.2.2.1
--- write.c     3 Oct 2003 23:25:48 -0000       1.2
+++ write.c     29 Mar 2004 23:43:09 -0000      1.2.2.1
@@ -698,7 +698,7 @@
 /*
  * Update and possibly write a cached page of an CFS file.
  *
- * XXX: Keep an eye on generic_file_read to make sure it doesn't do bad
+ * SSI_XXX: Keep an eye on generic_file_read to make sure it doesn't do bad
  * things with a page scheduled for an RPC call (e.g. invalidate it).
  */
 int

Index: cfs_svc.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfs_svc.c,v
retrieving revision 1.4
retrieving revision 1.4.2.1
diff -u -d -r1.4 -r1.4.2.1
--- cfs_svc.c   3 Oct 2003 23:25:47 -0000       1.4
+++ cfs_svc.c   29 Mar 2004 23:43:08 -0000      1.4.2.1
@@ -130,7 +130,7 @@
        cfs_mntinfo_t *mip;     /* CFS mount information. */
        int error;
 
-       /* XXX: avoid blocking for memory here */
+       /* SSI_XXX: avoid blocking for memory here */
 
        sb = current->fs->rootmnt->mnt_sb;
        mip = sbtocmi(sb);
@@ -500,18 +500,18 @@
        /* Now we have the Physical super-block set-up, lets really link
         * this guy up and set the CFS mount(s) back to UP.
         */
-       /* XXX */
+       /* SSI_XXX */
        /* mip->mi_mount_flags = mnt_flags */
        mip->mi_server = this_node;
        /* vfsp->vfs_dev = vfs_dev */
        sb->s_flags |= MS_CFS;          /* Mark as CFS stacked */
        mip->mi_pfs_sb = sb;
 
-       /* XXX: Should we copy final PFS flags to the CFS SB? */
+       /* SSI_XXX: Should we copy final PFS flags to the CFS SB? */
 
        err = cfs_send_rb(this_node, cfssb->s_ssidev);
 
-       /* XXX: Attach orphans here? */
+       /* SSI_XXX: Attach orphans here? */
 
        if (!err)
                err = cfs_send_rb_up(this_node, cfssb->s_ssidev);

Index: svrcfs.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/svrcfs.c,v
retrieving revision 1.4
retrieving revision 1.4.2.1
diff -u -d -r1.4 -r1.4.2.1
--- svrcfs.c    27 Oct 2003 23:17:59 -0000      1.4
+++ svrcfs.c    29 Mar 2004 23:43:08 -0000      1.4.2.1
@@ -614,12 +614,12 @@
                             agent, start, len);
                        break;
                case GIVEBACK:
-                       /* XXX: Handling incoming attributes */
+                       /* SSI_XXX: Handling incoming attributes */
                        svrcfstok_giveback_range(hp, type, oldmode,
                                newmode, agent, start, len);
                        break;
                case RETURN:
-                       /* XXX: Handling incoming attributes */
+                       /* SSI_XXX: Handling incoming attributes */
                        svrcfstok_return_range(hp, type, oldmode, newmode,
                                agent, start, len);
                        break;
@@ -628,7 +628,7 @@
                         * prevent loop by giving other processes a chance
                         * to run.
                         */
-                       /* NSC_XXX: We should have better mechanism to
+                       /* SSI_XXX: We should have better mechanism to
                         * prevent looping at client at server or
                         * bogus REVFAILs from clients.
                         */
@@ -683,7 +683,7 @@
                cfspol_setcli(hp, CFSPOL_TOKEN, agent, flags, delta);
                /* Let policy code send async token installs */
                /*
-                * NSC_XXX: Do I need another flag if for op == HINT I want
+                * SSI_XXX: Do I need another flag if for op == HINT I want
                 * sequenced installs or is sequencing good for
                 * op == REQUEST also?
                 */
@@ -753,7 +753,7 @@
                         * prevent loop by giving other processes a chance
                         * to run.
                         */
-                       /* NSC_XXX: We should have better mechanism to
+                       /* SSI_XXX: We should have better mechanism to
                         * prevent looping at client at server or
                         * bogus REVFAILs from clients.
                         */
@@ -1659,7 +1659,7 @@
        ctargs.cta_tokflags = 0;
        ctargs.cta_delta = -1;
 #endif
-       /* XXX: Send back empty cta_attr */
+       /* SSI_XXX: Send back empty cta_attr */
 
        for (i = 0; i < count ; i++) {
                ASSERT(toks[i].cntk_op == INSTALL);

Index: inode.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/inode.c,v
retrieving revision 1.9.2.6
retrieving revision 1.9.2.7
diff -u -d -r1.9.2.6 -r1.9.2.7
--- inode.c     26 Mar 2004 05:43:52 -0000      1.9.2.6
+++ inode.c     29 Mar 2004 23:43:08 -0000      1.9.2.7
@@ -844,7 +844,7 @@
        return 1;
 }
 
-#ifdef SSS_XXX
+#ifdef SSI_XXX
 /*
  * Only the handle differenciates files.  Really the handle includes dev/ino
  * so it is equivalent.  If we stack on NFS client and a weird NFS server

Index: cfs_subr.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfs_subr.c,v
retrieving revision 1.2.2.3
retrieving revision 1.2.2.4
diff -u -d -r1.2.2.3 -r1.2.2.4
--- cfs_subr.c  3 Mar 2004 00:14:37 -0000       1.2.2.3
+++ cfs_subr.c  29 Mar 2004 23:43:08 -0000      1.2.2.4
@@ -202,7 +202,7 @@
         */
 #ifdef NOTYET_BROKEN
        /*
-        * NSC_XXX: We can race with node-up of the lock backup node.
+        * SSI_XXX: We can race with node-up of the lock backup node.
         * We need to keep from rebuilding a lock backup node
         * from local lock information until we can finish
         * the local clean-up.
@@ -223,7 +223,7 @@
         */
        cfs_sysidcleanmirror(sysid);
 
-       /* NSC_XXX: We need to wait for all SBs which had
+       /* SSI_XXX: We need to wait for all SBs which had
         * mirror locks to go to the UP state, in case
         * any mirror lock rebuild messages were in flight
         * when the call above was made.
@@ -388,7 +388,7 @@
                        iput(ctoi(cnode));
                        continue;
                }
-               /* XXX: There was a check for CNOTHASHED, this might be
+               /* SSI_XXX: There was a check for CNOTHASHED, this might be
                 * I_FREEING in Linux, not sure if I can see an I_FREEING
                 * inode here.
                 */
@@ -746,7 +746,7 @@
 find_type(int mode)
 {
        mode &= S_IFMT;
-       /* XXX  search type_strs and return string */
+       /* SSI_XXX  search type_strs and return string */
 }
 
 void
@@ -799,7 +799,7 @@
 {
        char *filename;
 
-       /* XXXX: What about cfs_dir_inode_operations? */
+       /* SSI_XXX: What about cfs_dir_inode_operations? */
        if (ip->i_op == &cfs_file_inode_operations) {
                filename = ipfn(ip);
 
@@ -1284,13 +1284,13 @@
 
        mip = sbtocmi(sb);
 
-       /* XXX: Don't yet handle soft mount remount */
+       /* SSI_XXX: Don't yet handle soft mount remount */
        if (!CFS_SB_HARD_MIP(mip)) {
                retval = -EINVAL;
                goto out1;
        }
 
-       /* XXX: Shouldn't we call cfs_sb_wait_down() here instead? */
+       /* SSI_XXX: Shouldn't we call cfs_sb_wait_down() here instead? */
        /* We only remount down mounts */
        if (CFS_SB_UP_MIP(mip)) {
                retval = -EBUSY;
@@ -1370,18 +1370,18 @@
        /* Now we have the Physical super-block set-up, lets really link
         * this guy up and set the CFS mount(s) back to UP.
         */
-       /* XXX */
+       /* SSI_XXX */
        /* mip->mi_mount_flags = mnt_flags */
        mip->mi_server = this_node;
        /* sb->s_dev = sb_dev */
        sb->s_flags |= MS_CFS;          /* Mark as CFS stacked */
        mip->mi_pfs_sb = sb;
 
-       /* XXX: Should we copy final PFS flags to the CFS SB? */
+       /* SSI_XXX: Should we copy final PFS flags to the CFS SB? */
 
        err = cfs_send_rb(this_node, cfssb->s_ssidev);
 
-       /* XXX: Attach orphans here? */
+       /* SSI_XXX: Attach orphans here? */
 
        if (!err)
                err = cfs_send_rb_up(this_node, cfssb->s_ssidev);

Index: cfs_chard.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfs_chard.c,v
retrieving revision 1.2.2.1
retrieving revision 1.2.2.2
diff -u -d -r1.2.2.1 -r1.2.2.2
--- cfs_chard.c 26 Mar 2004 05:43:52 -0000      1.2.2.1
+++ cfs_chard.c 29 Mar 2004 23:43:08 -0000      1.2.2.2
@@ -474,7 +474,7 @@
                UNLOCK_COND_LOCK(&mip->mi_cond_lock);
                /* Clear device for server down case. */
 #ifdef SKIP
-               /* XXX: Can't clear this because it is needed in coordination
+               /* SSI_XXX: Can't clear this because it is needed in 
coordination
                 * with s_ssidev for ssi_get_super().  Don't know why this
                 * was done before.
                 */
@@ -569,7 +569,7 @@
        if (!error) {
                mip->mi_sb_state = MI_SB_STATE_REBUILD_HAVES;
 #ifdef SKIP
-               /* XXX: In Linux this can't be cleared */
+               /* SSI_XXX: In Linux this can't be cleared */
                sb->s_dev = dev;
                sb->s_flags &= ~SB_PFSFLAGS;
                sb->s_flags |= (sb_flags & SB_PFSFLAGS);



-------------------------------------------------------
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click



Try Searching:
servers, voip, java, networking, microsoft ...
<Prev in Thread] Current Thread [Next in Thread>
Index: cfstok.c
===================================================================
RCS file: /cvsroot/ssic-linux/openssi/kernel/cluster/ssi/cfs/Attic/cfstok.c,v
retrieving revision 1.1.2.4
retrieving revision 1.1.2.5
diff -u -d -r1.1.2.4 -r1.1.2.5
--- cfstok.c    3 Oct 2003 23:25:47 -0000       1.1.2.4
+++ cfstok.c    29 Mar 2004 23:43:08 -0000      1.1.2.5
@@ -305,7 +305,7 @@
                         * check for HELD, if not, don't waste time to
                         * do the next req. break so thst user of this
                         * code function function ship;
                         * NSC_XXX: needs better return value
                         */
                        if ( retval != CFSTOK_HELD )
                                return retval;
@@ -1023,7 +1023,7 @@
        range_off_t len)
 {
        /*
         * NSC_XXX: do i have to clean up holdlist ?
         */
 
        CFSTOK_XLOCK( itoc(ip));/* exclusive lock token info in cfs inode*/
@@ -1177,7 +1177,7 @@
        object_t obj;
 
        /*
-        * NSC_XXX:
+        * SSI_XXX:
         * you have to check for HOLDREQ's made before and
         * update holdlist.
         */
@@ -1276,7 +1276,7 @@
                mhtok_giveback(&obj, &(itoc(ip)->c_mhold), this_node);
        }
 
        /* NSC_XXX: Sequencing  - Because the cnode is going away can
         * we deadlock by not calling process_msgs() for every giveback?
         */
        /* Must get returns to server before cnode goes away */
@@ -1357,7 +1357,7 @@
        size = NOSIZE;
        if (type == CFSTOK_SIZE && oldmode == CFSTOK_RDWR) {
                size = cp->c_send_size;
                /* NSC_XXX: When install races are occuring, don't know if
                 * this should field should be lock protected.
                 */
                cp->c_send_size = NOSIZE;
@@ -1434,7 +1434,7 @@
 #else
                        0,
 #endif
-                       seq, this_node,  /* XXX: attr */ 0 );
+                       seq, this_node,  /* SSI_XXX: attr */ 0 );
            else
                cfs_tokmsg(fhp, type, op, oldmode, newmode,
                    agent, (range_off_t)start, len,
@@ -1453,7 +1453,7 @@
 #else
                        0,
 #endif
-                       0, this_node, /* XXX: attr */ 0 );
+                       0, this_node, /* SSI_XXX: attr */ 0 );
            goto out;
 
        }
@@ -1468,7 +1468,7 @@
        ctargs.cta_seq = seq;
        ctargs.cta_fromnode = this_node;
        /* Send along in case this is a ATTR token RETURN, GIVEBACK or QRYRET */
        /* XXX: Load cta_attr attributes from inode */
 
 #ifdef SSI_CFS_POLICY
        ctargs.cta_tokflags = cfspol_getcliflgs(ip);
@@ -1548,7 +1548,7 @@
         * possibly doing expensive flushing, mark this operation
         * complete as far as the sequencing is concerned.
         */
        /* NSC_XXX: Should I assert that CFSTOK_XLOCKOWNED()? */
        if (direct)
                tokseq_early_accept(cfs_tsp, itocmi(ip)->mi_server);
 
@@ -1931,7 +1931,7 @@
 
 int cfs_default_delay = 1 * HZ;
 
 /* NSC_XXX: If the delay is 0, maybe this routine should use
  * a heuristic algorithm to determine a reasonable delay value.
  */
 void
@@ -2088,14 +2088,14 @@
                /* Set up svrcfstok with MHOLD and other cnode state */
                error = cfstok_start_svrcfstok(ct);
 #ifdef NOTYET
                /* NSC_XXX: On server failure, we should
                 * just return an error here.
                 */
                if (error == EREMOTE)
                        return error;
 #endif
 
        /* NSC_XXX: This gets turned on to fix for PTS32873 */
 #ifdef NOTYET
                /* Couldn't set up server structure, just mark as hidden */
                if (error) {
@@ -2238,7 +2238,7 @@
                /* Just for convenience we will check for open or maps
                 * for read when ATIME is being queried.
                 *
                 * NSC_XXX: Writers mark ATIME sometimes?
                 */
                if ( S_ISREG(ip->i_mode) &&
                    (itoc(ip)->c_rmapcnt + itoc(ip)->c_ropncnt) == 0 &&
@@ -305,7 +305,7 @@
                         * do the next req. break so thst user of this
                         * code function function ship;
-                        * NSC_XXX: needs better return value
+                        * SSI_XXX: needs better return value
                         */
                        if ( retval != CFSTOK_HELD )
@@ -1023,7 +1023,7 @@
 {
        /*
-        * NSC_XXX: do i have to clean up holdlist ?
+        * SSI_XXX: do i have to clean up holdlist ?
         */
 
@@ -1276,7 +1276,7 @@
        }
 
-       /* NSC_XXX: Sequencing  - Because the cnode is going away can
+       /* SSI_XXX: Sequencing  - Because the cnode is going away can
         * we deadlock by not calling process_msgs() for every giveback?
         */
@@ -1357,7 +1357,7 @@
        if (type == CFSTOK_SIZE && oldmode == CFSTOK_RDWR) {
                size = cp->c_send_size;
-               /* NSC_XXX: When install races are occuring, don't know if
+               /* SSI_XXX: When install races are occuring, don't know if
                 * this should field should be lock protected.
                 */
@@ -1468,7 +1468,7 @@
        ctargs.cta_fromnode = this_node;
        /* Send along in case this is a ATTR token RETURN, GIVEBACK or QRYRET */
-       /* XXX: Load cta_attr attributes from inode */
+       /* SSI_XXX: Load cta_attr attributes from inode */
 
 #ifdef SSI_CFS_POLICY
@@ -1548,7 +1548,7 @@
         * complete as far as the sequencing is concerned.
         */
-       /* NSC_XXX: Should I assert that CFSTOK_XLOCKOWNED()? */
+       /* SSI_XXX: Should I assert that CFSTOK_XLOCKOWNED()? */
        if (direct)
                tokseq_early_accept(cfs_tsp, itocmi(ip)->mi_server);
@@ -1931,7 +1931,7 @@
 int cfs_default_delay = 1 * HZ;
 
-/* NSC_XXX: If the delay is 0, maybe this routine should use
+/* SSI_XXX: If the delay is 0, maybe this routine should use
  * a heuristic algorithm to determine a reasonable delay value.
  */
@@ -2088,14 +2088,14 @@
                error = cfstok_start_svrcfstok(ct);
 #ifdef NOTYET
-               /* NSC_XXX: On server failure, we should
+               /* SSI_XXX: On server failure, we should
                 * just return an error here.
                 */
@@ -2088,14 +2088,14 @@
 #endif
 
-       /* NSC_XXX: This gets turned on to fix for PTS32873 */
+       /* SSI_XXX: This gets turned on to fix for PTS32873 */
 #ifdef NOTYET
                /* Couldn't set up server structure, just mark as hidden */
@@ -2238,7 +2238,7 @@
                 * for read when ATIME is being queried.
                 *
-                * NSC_XXX: Writers mark ATIME sometimes?
+                * SSI_XXX: Writers mark ATIME sometimes?
                 */
                if ( S_ISREG(ip->i_mode) &&
